# coding: utf-8
from __future__ import unicode_literals

import re

import pytest

from ..default import get_default_filter


words_filter = get_default_filter()


def test_is_word_good():
    cases = [
        'хлебало', 'хлебала', 'скипидар',
        'колебания', 'колебание', 'колебаний',
        'заколебал', 'заколебать', 'закалебал', 'зоколебать',
        'рубля', 'стебель', 'страховка', 'страховку', 'страховки',
        'оскорблять', 'оскорбляешь', 'оскорблял',
        'влюблять', 'влюбляешься',
        'подстрахуй', 'застрахуй', 'подстрахует', 'застрахует', 'застрахуешься',
        'мебельный',
        'употреблять', 'употребляешь', 'употреблял',
        'истреблять', 'истребляешь', 'истреблял',
        'страх', 'страха',
    ]
    for word in cases:
        assert words_filter.is_word_good(word) is True


def test_is_word_bad():
    good = [
        'хлебало', 'хлебала', 'скипидар',
    ]
    bad = [
        'пизда', 'пиздец', 'пизды', 'пезда',
        'пи3да', 'пиzдец', 'pizdec', 'pizdets', 'pezdets', 'pi3dec',
        'хуй', 'хуйло', 'хуюшки',
        'охуевший', 'охуел', 'охуеть',
        'пидор', 'пидар', 'пидер', 'пидр',
        'ебаный', 'ебака', 'ебало', 'ёбаный', 'ебать',
        'уебан', 'уёбок', 'уебот',
        'ебло', 'ёбла', 'ёбли', 'ебли',
        'выеб', 'выёб', 'выебли', 'выебали',
        'бля', 'говно', 'гавно', 'мудак', 'мудачьё',
        'гондон', 'чмо', 'дерьмо', 'шлюха', 'залупа', 'золупа',
        'манда', 'монда', 'сучара', 'далбаёб', 'долбоёб', 'далбаёбы',
    ]
    for word in bad:
        assert words_filter.is_word_bad(word) is True

    for word in good:
        assert words_filter.is_word_bad(word) is False


def test_is_word_bad_case_insensitive():
    bad = ['пизда', 'ПИЗДА']
    for word in bad:
        assert words_filter.is_word_bad(word) is True


def test_is_word_good_case_insensitive():
    cases = {
        'скипидар': True,
        'СКИПИДАР': True,
    }
    for k, v in cases.items():
        assert words_filter.is_word_good(k) == v


def test_find_bad_word_matches():
    cases = {
        ' пиздец пизда опиздеть вот это да': ['пиздец', 'пизда', 'опиздеть'],
        'хуйло хуй хуёвый хуясе пирожок': ['хуйло', 'хуй', 'хуёвый', 'хуясе'],
        'трамвай пидар пидараз пидор пидер пидераст локомотив': ['пидар', 'пидараз', 'пидор', 'пидер', 'пидераст'],
        'собака ебаный и ёбаный ебало ебака ебатуй ебразерс': ['ебаный', 'ёбаный', 'ебало', 'ебака', 'ебатуй'],
        'уебался уебать уебак уебок уёбок': ['уебался', 'уебать', 'уебак', 'уебок', 'уёбок'],
        'охуевший охуеть охуел ОХУЕТЬ Охуел охуеваю': ['охуевший', 'охуеть', 'охуел', 'ОХУЕТЬ', 'Охуел', 'охуеваю'],
    }

    for k, v in cases.items():
        assert [m.group() for m in words_filter.find_bad_word_matches(k)] == v


def test_find_bad_word_matches_without_good_words():
    cases = {
        'пидар скипидар пидор': ['пидар', 'пидор'],
        'ебало хлебало': ['ебало'],
    }
    for k, v in cases.items():
        assert [m.group() for m in words_filter.find_bad_word_matches_without_good_words(k)] == v


def test_mask_text_range():
    words_filter.mask_text_range('0123456789', 3, 5) == '012**56789'
    words_filter.mask_text_range('0123456789', 1, 6, symbol='-') == '-----06789'


def test_mask_bad_words():
    cases = {
        'Охуеть, товарищи! Это пиздец! Хуй! Вчера ехал на газели — уебался в камаз! Хуй.': (
            '******, товарищи! Это ******! ***! Вчера ехал на газели — ******* в камаз! ***.'
        ),
        'Да охуеть блять, вы что, суки, заебали, охуели совсем в конец уже!': (
            'Да ****** *****, вы что, суки, *******, ****** совсем в конец уже!'
        ),
        u'Долбоёбам и любой тупой пизде вход закрыт, нахуй и не ебёт.': (
            u'********* и любой тупой ***** вход закрыт, ***** и не ****.'
        ),
    }

    for k, v in cases.items():
        assert words_filter.mask_bad_words(k) == v
